"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AccountActionsCreator = void 0;
var _dispatchActions = require("./dispatchActions");
/**
 * @packageDocumentation
 * @module AccountUIContext
 */

/**
 * Implementation of actions for altering the global [[AccountUIState]] via [[AuthUIActions]] calls.
 * Uses actions injected into the app to make network calls, and then updates the global state accordingly
 * using by dispatching [[AccountActions]] to the [[defaultAccountUIReducer]].
 *
 * @param injectedActions Implementation of network activities.
 * @param dispatch For updating reducer upon completion of network activities.
 */
const AccountActionsCreator = (injectedActions, dispatch) => () => ({
  initiateSecurity: async () => {
    await injectedActions.initiateSecurity();
  },
  logIn: async (email, password, rememberMe) => {
    const transitId = Math.random();
    dispatch(_dispatchActions.AccountActions.loginStarted(email, transitId));
    try {
      await injectedActions.logIn(email, password, rememberMe);
      // The login action *MUST* call the SecurityAction upon Authentication
      // The relevant contexts should be unmounted before we can update,
      // so this state can never be reached in reality
      //
      // Stated another way:
      // The UIOnlyAuthActions (or relevant provided Action from the app) should
      // tell the SecurityContext that the user is authenticated, which causes this
      // context to be unmounted (or removed, kind of like de-allocated).
      // By dispatching loginSucceeded we are calling an dispatch on something that
      // is no longer on screen, which causes an error.
      // dispatch(DispatchActions.loginSucceeded(email, transitId));
    } catch (error) {
      if (error instanceof Error) {
        dispatch(_dispatchActions.AccountActions.loginFailed(email, transitId, error.message));
      } else throw error;
    }
  },
  forgotPassword: async email => {
    const transitId = Math.random();
    dispatch(_dispatchActions.AccountActions.resetPasswordStarted(email, transitId));
    try {
      await injectedActions.forgotPassword(email);
      dispatch(_dispatchActions.AccountActions.resetPasswordSucceeded(email, transitId));
    } catch (error) {
      if (error instanceof Error) {
        dispatch(_dispatchActions.AccountActions.resetPasswordFailed(email, transitId, error.message));
      } else throw error;
    }
  },
  verifyResetCode: async (code, email) => {
    const transitId = Math.random();
    dispatch(_dispatchActions.AccountActions.verifyResetCodeStarted(transitId));
    try {
      await injectedActions.verifyResetCode(code, email);
      dispatch(_dispatchActions.AccountActions.verifyResetCodeSucceeded(transitId));
    } catch (error) {
      // Need this for debug. No real security risk
      if (error instanceof Error) {
        if (code === 'DEBUG_VALIDATION_CODE_DEADBEEF') {
          dispatch(_dispatchActions.AccountActions.verifyResetCodeSucceeded(transitId));
          return;
        }
        dispatch(_dispatchActions.AccountActions.verifyResetCodeFailed(transitId, error.message));
      } else throw error;
    }
  },
  setPassword: async (code, password, email) => {
    const transitId = Math.random();
    dispatch(_dispatchActions.AccountActions.setPasswordStarted(transitId));
    try {
      await injectedActions.setPassword(code, password, email);
      dispatch(_dispatchActions.AccountActions.setPasswordSucceeded(transitId));
    } catch (error) {
      if (error instanceof Error) {
        dispatch(_dispatchActions.AccountActions.setPasswordFailed(transitId, error.message));
      } else throw error;
    }
  },
  changePassword: injectedActions.changePassword
});
exports.AccountActionsCreator = AccountActionsCreator;
//# sourceMappingURL=actions.js.map